import unittest
import time  # ✅ FIXED: Import time module
import sys
import os

# Ensure the test script finds bssauth properly
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from bssauth import bssauth
from cryptography.fernet import Fernet

class TestBssAuth(unittest.TestCase):
    def setUp(self):
        self.key = bssauth.generate_key()
        self.user_id = "user_123"

    def test_token_generation_and_validation(self):
        token = bssauth.generate_token(self.user_id, self.key)
        self.assertTrue(bssauth.validate_token(token, self.key))

    def test_expired_token(self):
        token = bssauth.generate_token(self.user_id, self.key, expiry=-10)
        self.assertFalse(bssauth.validate_token(token, self.key))

    def test_device_fingerprint(self):
        fingerprint1 = bssauth.device_fingerprint()
        fingerprint2 = bssauth.device_fingerprint()
        self.assertNotEqual(fingerprint1, fingerprint2)

    def test_anomaly_detection(self):
        """✅ FIXED: Ensure frequent login attempts to trigger an anomaly"""
        current_time = time.time()
        attempts = [{"timestamp": current_time - i} for i in [2, 3, 4]]  # More frequent logins
        self.assertTrue(bssauth.detect_anomaly(attempts))


if __name__ == "__main__":
    unittest.main()
